
#include <glib.h>

// Disable the 'const' function attribute of the get_type() functions.
// GCC would optimize them out because we don't use the return value.
#undef  G_GNUC_CONST
#define G_GNUC_CONST /* empty */

#include <gtkmm/wrap_init.h>
#include <glibmm/error.h>
#include <glibmm/object.h>

// #include the widget headers so that we can call the get_type() static methods:

#include "./accelgroup.h"
#include "./accellabel.h"
#include "./adjustment.h"
#include "./alignment.h"
#include "./arrow.h"
#include "./aspectframe.h"
#include "./bin.h"
#include "./box.h"
#include "./button.h"
#include "./buttonbox.h"
#include "./calendar.h"
#include "./celleditable.h"
#include "./checkbutton.h"
#include "./checkmenuitem.h"
#include "./cellrenderer.h"
#include "./cellrendererpixbuf.h"
#include "./cellrenderertext.h"
#include "./cellrenderertoggle.h"
#include "./colorselection.h"
#include "./combo.h"
#include "./container.h"
#include "./curve.h"
#include "./dialog.h"
#include "./drawingarea.h"
#include "./editable.h"
#include "./entry.h"
#include "./enums.h"
#include "./eventbox.h"
#include "./fileselection.h"
#include "./fixed.h"
#include "./fontselection.h"
#include "./frame.h"
#include "./handlebox.h"
#include "./iconfactory.h"
#include "./iconset.h"
#include "./iconsource.h"
#include "./image.h"
#include "./imagemenuitem.h"
#include "./inputdialog.h"
#include "./invisible.h"
#include "./item.h"
#include "./label.h"
#include "./layout.h"
#include "./liststore.h"
#include "./main.h"
#include "./menu.h"
#include "./menubar.h"
#include "./menuitem.h"
#include "./menushell.h"
#include "./messagedialog.h"
#include "./misc.h"
#include "./notebook.h"
#include "./object.h"
#include "./optionmenu.h"
#include "./paned.h"
#include "./progressbar.h"
#include "./radiobutton.h"
#include "./radiomenuitem.h"
#include "./range.h"
#include "./rc.h"
#include "./ruler.h"
#include "./scale.h"
#include "./scrollbar.h"
#include "./scrolledwindow.h"
#include "./separator.h"
#include "./separatormenuitem.h"
#include "./settings.h"
#include "./sizegroup.h"
#include "./spinbutton.h"
#include "./statusbar.h"
#include "./stockitem.h"
#include "./style.h"
#include "./table.h"
#include "./tearoffmenuitem.h"
#include "./textattributes.h"
#include "./textbuffer.h"
#include "./textchildanchor.h"
#include "./textiter.h"
#include "./textmark.h"
#include "./texttag.h"
#include "./texttagtable.h"
#include "./textview.h"
#include "./togglebutton.h"
#include "./toolbar.h"
#include "./tooltips.h"
#include "./treedragdest.h"
#include "./treedragsource.h"
#include "./treepath.h"
#include "./treeselection.h"
#include "./treesortable.h"
#include "./treerowreference.h"
#include "./treeiter.h"
#include "./treemodel.h"
#include "./treestore.h"
#include "./treeview.h"
#include "./treeviewcolumn.h"
#include "./viewport.h"
#include "./widget.h"
#include "./window.h"
#include "./plug.h"
#include "./socket.h"

extern "C"
{

//Declarations of the *_get_type() functions:

GType gtk_accel_group_get_type(void);
GType gtk_accel_label_get_type(void);
GType gtk_adjustment_get_type(void);
GType gtk_alignment_get_type(void);
GType gtk_arrow_get_type(void);
GType gtk_aspect_frame_get_type(void);
GType gtk_bin_get_type(void);
GType gtk_box_get_type(void);
GType gtk_button_get_type(void);
GType gtk_button_box_get_type(void);
GType gtk_calendar_get_type(void);
GType gtk_cell_renderer_get_type(void);
GType gtk_cell_renderer_pixbuf_get_type(void);
GType gtk_cell_renderer_text_get_type(void);
GType gtk_cell_renderer_toggle_get_type(void);
GType gtk_check_button_get_type(void);
GType gtk_check_menu_item_get_type(void);
GType gtk_color_selection_get_type(void);
GType gtk_color_selection_dialog_get_type(void);
GType gtk_combo_get_type(void);
GType gtk_list_get_type(void);
GType gtk_list_item_get_type(void);
GType gtk_container_get_type(void);
GType gtk_curve_get_type(void);
GType gtk_dialog_get_type(void);
GType gtk_drawing_area_get_type(void);
GType gtk_entry_get_type(void);
GType gtk_event_box_get_type(void);
GType gtk_file_selection_get_type(void);
GType gtk_fixed_get_type(void);
GType gtk_font_selection_get_type(void);
GType gtk_font_selection_dialog_get_type(void);
GType gtk_frame_get_type(void);
GType gtk_gamma_curve_get_type(void);
GType gtk_hbox_get_type(void);
GType gtk_hbutton_box_get_type(void);
GType gtk_hpaned_get_type(void);
GType gtk_hruler_get_type(void);
GType gtk_hscale_get_type(void);
GType gtk_hscrollbar_get_type(void);
GType gtk_hseparator_get_type(void);
GType gtk_handle_box_get_type(void);
GType gtk_icon_factory_get_type(void);
GType gtk_image_get_type(void);
GType gtk_image_menu_item_get_type(void);
GType gtk_input_dialog_get_type(void);
GType gtk_invisible_get_type(void);
GType gtk_item_get_type(void);
GType gtk_label_get_type(void);
GType gtk_layout_get_type(void);
GType gtk_list_store_get_type(void);
GType gtk_menu_get_type(void);
GType gtk_menu_bar_get_type(void);
GType gtk_menu_item_get_type(void);
GType gtk_menu_shell_get_type(void);
GType gtk_message_dialog_get_type(void);
GType gtk_misc_get_type(void);
GType gtk_notebook_get_type(void);
GType gtk_object_get_type(void);
GType gtk_option_menu_get_type(void);
GType gtk_paned_get_type(void);
#ifndef GTKMM_WIN32
GType gtk_plug_get_type(void);
#endif //GTKMM_WIN32
GType gtk_progress_bar_get_type(void);
GType gtk_radio_button_get_type(void);
GType gtk_radio_menu_item_get_type(void);
GType gtk_range_get_type(void);
GType gtk_rc_style_get_type(void);
GType gtk_ruler_get_type(void);
GType gtk_scale_get_type(void);
GType gtk_scrollbar_get_type(void);
GType gtk_scrolled_window_get_type(void);
GType gtk_separator_get_type(void);
GType gtk_separator_menu_item_get_type(void);
GType gtk_settings_get_type(void);
GType gtk_size_group_get_type(void);
#ifndef GTKMM_WIN32
GType gtk_socket_get_type(void);
#endif //GTKMM_WIN32
GType gtk_spin_button_get_type(void);
GType gtk_statusbar_get_type(void);
GType gtk_style_get_type(void);
GType gtk_table_get_type(void);
GType gtk_tearoff_menu_item_get_type(void);
GType gtk_text_buffer_get_type(void);
GType gtk_text_child_anchor_get_type(void);
GType gtk_text_mark_get_type(void);
GType gtk_text_tag_get_type(void);
GType gtk_text_tag_table_get_type(void);
GType gtk_text_view_get_type(void);
GType gtk_toggle_button_get_type(void);
GType gtk_toolbar_get_type(void);
GType gtk_tooltips_get_type(void);
GType gtk_tree_selection_get_type(void);
GType gtk_tree_store_get_type(void);
GType gtk_tree_view_get_type(void);
GType gtk_tree_view_column_get_type(void);
GType gtk_vbox_get_type(void);
GType gtk_vbutton_box_get_type(void);
GType gtk_vpaned_get_type(void);
GType gtk_vruler_get_type(void);
GType gtk_vscale_get_type(void);
GType gtk_vscrollbar_get_type(void);
GType gtk_vseparator_get_type(void);
GType gtk_viewport_get_type(void);
GType gtk_widget_get_type(void);
GType gtk_window_get_type(void);
GType gtk_window_group_get_type(void);

//Declarations of the *_error_quark() functions:

} // extern "C"


//Declarations of the *_Class::wrap_new() methods, instead of including all the private headers:

namespace Gtk {  class AccelGroup_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class AccelLabel_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Adjustment_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Alignment_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Arrow_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class AspectFrame_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Bin_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Box_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Button_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class ButtonBox_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Calendar_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class CellRenderer_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class CellRendererPixbuf_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class CellRendererText_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class CellRendererToggle_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class CheckButton_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class CheckMenuItem_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class ColorSelection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class ColorSelectionDialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Combo_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class ComboDropDown_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class ComboDropDownItem_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Container_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Curve_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Dialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class DrawingArea_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Entry_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class EventBox_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class FileSelection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Fixed_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class FontSelection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class FontSelectionDialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Frame_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class GammaCurve_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class HBox_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class HButtonBox_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class HPaned_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class HRuler_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class HScale_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class HScrollbar_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class HSeparator_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class HandleBox_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class IconFactory_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Image_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class ImageMenuItem_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class InputDialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Invisible_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Item_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Label_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Layout_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class ListStore_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Menu_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class MenuBar_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class MenuItem_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class MenuShell_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class MessageDialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Misc_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Notebook_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Object_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class OptionMenu_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Paned_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
#ifndef GTKMM_WIN32
namespace Gtk {  class Plug_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
#endif //GTKMM_WIN32
namespace Gtk {  class ProgressBar_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class RadioButton_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class RadioMenuItem_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Range_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class RcStyle_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Ruler_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Scale_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Scrollbar_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class ScrolledWindow_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Separator_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class SeparatorMenuItem_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Settings_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class SizeGroup_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
#ifndef GTKMM_WIN32
namespace Gtk {  class Socket_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
#endif //GTKMM_WIN32
namespace Gtk {  class SpinButton_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Statusbar_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Style_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Table_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class TearoffMenuItem_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class TextBuffer_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class TextChildAnchor_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class TextMark_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class TextTag_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class TextTagTable_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class TextView_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class ToggleButton_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Toolbar_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Tooltips_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class TreeSelection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class TreeStore_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class TreeView_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class TreeViewColumn_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class VBox_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class VButtonBox_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class VPaned_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class VRuler_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class VScale_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class VScrollbar_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class VSeparator_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Viewport_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Widget_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class Window_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
namespace Gtk {  class WindowGroup_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }

namespace Gtk { 

void wrap_init()
{
  // Register Error domains:

// Map gtypes to gtkmm wrapper-creation functions:
  Glib::wrap_register(gtk_accel_group_get_type(), &Gtk::AccelGroup_Class::wrap_new);
  Glib::wrap_register(gtk_accel_label_get_type(), &Gtk::AccelLabel_Class::wrap_new);
  Glib::wrap_register(gtk_adjustment_get_type(), &Gtk::Adjustment_Class::wrap_new);
  Glib::wrap_register(gtk_alignment_get_type(), &Gtk::Alignment_Class::wrap_new);
  Glib::wrap_register(gtk_arrow_get_type(), &Gtk::Arrow_Class::wrap_new);
  Glib::wrap_register(gtk_aspect_frame_get_type(), &Gtk::AspectFrame_Class::wrap_new);
  Glib::wrap_register(gtk_bin_get_type(), &Gtk::Bin_Class::wrap_new);
  Glib::wrap_register(gtk_box_get_type(), &Gtk::Box_Class::wrap_new);
  Glib::wrap_register(gtk_button_get_type(), &Gtk::Button_Class::wrap_new);
  Glib::wrap_register(gtk_button_box_get_type(), &Gtk::ButtonBox_Class::wrap_new);
  Glib::wrap_register(gtk_calendar_get_type(), &Gtk::Calendar_Class::wrap_new);
  Glib::wrap_register(gtk_cell_renderer_get_type(), &Gtk::CellRenderer_Class::wrap_new);
  Glib::wrap_register(gtk_cell_renderer_pixbuf_get_type(), &Gtk::CellRendererPixbuf_Class::wrap_new);
  Glib::wrap_register(gtk_cell_renderer_text_get_type(), &Gtk::CellRendererText_Class::wrap_new);
  Glib::wrap_register(gtk_cell_renderer_toggle_get_type(), &Gtk::CellRendererToggle_Class::wrap_new);
  Glib::wrap_register(gtk_check_button_get_type(), &Gtk::CheckButton_Class::wrap_new);
  Glib::wrap_register(gtk_check_menu_item_get_type(), &Gtk::CheckMenuItem_Class::wrap_new);
  Glib::wrap_register(gtk_color_selection_get_type(), &Gtk::ColorSelection_Class::wrap_new);
  Glib::wrap_register(gtk_color_selection_dialog_get_type(), &Gtk::ColorSelectionDialog_Class::wrap_new);
  Glib::wrap_register(gtk_combo_get_type(), &Gtk::Combo_Class::wrap_new);
  Glib::wrap_register(gtk_list_get_type(), &Gtk::ComboDropDown_Class::wrap_new);
  Glib::wrap_register(gtk_list_item_get_type(), &Gtk::ComboDropDownItem_Class::wrap_new);
  Glib::wrap_register(gtk_container_get_type(), &Gtk::Container_Class::wrap_new);
  Glib::wrap_register(gtk_curve_get_type(), &Gtk::Curve_Class::wrap_new);
  Glib::wrap_register(gtk_dialog_get_type(), &Gtk::Dialog_Class::wrap_new);
  Glib::wrap_register(gtk_drawing_area_get_type(), &Gtk::DrawingArea_Class::wrap_new);
  Glib::wrap_register(gtk_entry_get_type(), &Gtk::Entry_Class::wrap_new);
  Glib::wrap_register(gtk_event_box_get_type(), &Gtk::EventBox_Class::wrap_new);
  Glib::wrap_register(gtk_file_selection_get_type(), &Gtk::FileSelection_Class::wrap_new);
  Glib::wrap_register(gtk_fixed_get_type(), &Gtk::Fixed_Class::wrap_new);
  Glib::wrap_register(gtk_font_selection_get_type(), &Gtk::FontSelection_Class::wrap_new);
  Glib::wrap_register(gtk_font_selection_dialog_get_type(), &Gtk::FontSelectionDialog_Class::wrap_new);
  Glib::wrap_register(gtk_frame_get_type(), &Gtk::Frame_Class::wrap_new);
  Glib::wrap_register(gtk_gamma_curve_get_type(), &Gtk::GammaCurve_Class::wrap_new);
  Glib::wrap_register(gtk_hbox_get_type(), &Gtk::HBox_Class::wrap_new);
  Glib::wrap_register(gtk_hbutton_box_get_type(), &Gtk::HButtonBox_Class::wrap_new);
  Glib::wrap_register(gtk_hpaned_get_type(), &Gtk::HPaned_Class::wrap_new);
  Glib::wrap_register(gtk_hruler_get_type(), &Gtk::HRuler_Class::wrap_new);
  Glib::wrap_register(gtk_hscale_get_type(), &Gtk::HScale_Class::wrap_new);
  Glib::wrap_register(gtk_hscrollbar_get_type(), &Gtk::HScrollbar_Class::wrap_new);
  Glib::wrap_register(gtk_hseparator_get_type(), &Gtk::HSeparator_Class::wrap_new);
  Glib::wrap_register(gtk_handle_box_get_type(), &Gtk::HandleBox_Class::wrap_new);
  Glib::wrap_register(gtk_icon_factory_get_type(), &Gtk::IconFactory_Class::wrap_new);
  Glib::wrap_register(gtk_image_get_type(), &Gtk::Image_Class::wrap_new);
  Glib::wrap_register(gtk_image_menu_item_get_type(), &Gtk::ImageMenuItem_Class::wrap_new);
  Glib::wrap_register(gtk_input_dialog_get_type(), &Gtk::InputDialog_Class::wrap_new);
  Glib::wrap_register(gtk_invisible_get_type(), &Gtk::Invisible_Class::wrap_new);
  Glib::wrap_register(gtk_item_get_type(), &Gtk::Item_Class::wrap_new);
  Glib::wrap_register(gtk_label_get_type(), &Gtk::Label_Class::wrap_new);
  Glib::wrap_register(gtk_layout_get_type(), &Gtk::Layout_Class::wrap_new);
  Glib::wrap_register(gtk_list_store_get_type(), &Gtk::ListStore_Class::wrap_new);
  Glib::wrap_register(gtk_menu_get_type(), &Gtk::Menu_Class::wrap_new);
  Glib::wrap_register(gtk_menu_bar_get_type(), &Gtk::MenuBar_Class::wrap_new);
  Glib::wrap_register(gtk_menu_item_get_type(), &Gtk::MenuItem_Class::wrap_new);
  Glib::wrap_register(gtk_menu_shell_get_type(), &Gtk::MenuShell_Class::wrap_new);
  Glib::wrap_register(gtk_message_dialog_get_type(), &Gtk::MessageDialog_Class::wrap_new);
  Glib::wrap_register(gtk_misc_get_type(), &Gtk::Misc_Class::wrap_new);
  Glib::wrap_register(gtk_notebook_get_type(), &Gtk::Notebook_Class::wrap_new);
  Glib::wrap_register(gtk_object_get_type(), &Gtk::Object_Class::wrap_new);
  Glib::wrap_register(gtk_option_menu_get_type(), &Gtk::OptionMenu_Class::wrap_new);
  Glib::wrap_register(gtk_paned_get_type(), &Gtk::Paned_Class::wrap_new);
#ifndef GTKMM_WIN32
  Glib::wrap_register(gtk_plug_get_type(), &Gtk::Plug_Class::wrap_new);
#endif //GTKMM_WIN32
  Glib::wrap_register(gtk_progress_bar_get_type(), &Gtk::ProgressBar_Class::wrap_new);
  Glib::wrap_register(gtk_radio_button_get_type(), &Gtk::RadioButton_Class::wrap_new);
  Glib::wrap_register(gtk_radio_menu_item_get_type(), &Gtk::RadioMenuItem_Class::wrap_new);
  Glib::wrap_register(gtk_range_get_type(), &Gtk::Range_Class::wrap_new);
  Glib::wrap_register(gtk_rc_style_get_type(), &Gtk::RcStyle_Class::wrap_new);
  Glib::wrap_register(gtk_ruler_get_type(), &Gtk::Ruler_Class::wrap_new);
  Glib::wrap_register(gtk_scale_get_type(), &Gtk::Scale_Class::wrap_new);
  Glib::wrap_register(gtk_scrollbar_get_type(), &Gtk::Scrollbar_Class::wrap_new);
  Glib::wrap_register(gtk_scrolled_window_get_type(), &Gtk::ScrolledWindow_Class::wrap_new);
  Glib::wrap_register(gtk_separator_get_type(), &Gtk::Separator_Class::wrap_new);
  Glib::wrap_register(gtk_separator_menu_item_get_type(), &Gtk::SeparatorMenuItem_Class::wrap_new);
  Glib::wrap_register(gtk_settings_get_type(), &Gtk::Settings_Class::wrap_new);
  Glib::wrap_register(gtk_size_group_get_type(), &Gtk::SizeGroup_Class::wrap_new);
#ifndef GTKMM_WIN32
  Glib::wrap_register(gtk_socket_get_type(), &Gtk::Socket_Class::wrap_new);
#endif //GTKMM_WIN32
  Glib::wrap_register(gtk_spin_button_get_type(), &Gtk::SpinButton_Class::wrap_new);
  Glib::wrap_register(gtk_statusbar_get_type(), &Gtk::Statusbar_Class::wrap_new);
  Glib::wrap_register(gtk_style_get_type(), &Gtk::Style_Class::wrap_new);
  Glib::wrap_register(gtk_table_get_type(), &Gtk::Table_Class::wrap_new);
  Glib::wrap_register(gtk_tearoff_menu_item_get_type(), &Gtk::TearoffMenuItem_Class::wrap_new);
  Glib::wrap_register(gtk_text_buffer_get_type(), &Gtk::TextBuffer_Class::wrap_new);
  Glib::wrap_register(gtk_text_child_anchor_get_type(), &Gtk::TextChildAnchor_Class::wrap_new);
  Glib::wrap_register(gtk_text_mark_get_type(), &Gtk::TextMark_Class::wrap_new);
  Glib::wrap_register(gtk_text_tag_get_type(), &Gtk::TextTag_Class::wrap_new);
  Glib::wrap_register(gtk_text_tag_table_get_type(), &Gtk::TextTagTable_Class::wrap_new);
  Glib::wrap_register(gtk_text_view_get_type(), &Gtk::TextView_Class::wrap_new);
  Glib::wrap_register(gtk_toggle_button_get_type(), &Gtk::ToggleButton_Class::wrap_new);
  Glib::wrap_register(gtk_toolbar_get_type(), &Gtk::Toolbar_Class::wrap_new);
  Glib::wrap_register(gtk_tooltips_get_type(), &Gtk::Tooltips_Class::wrap_new);
  Glib::wrap_register(gtk_tree_selection_get_type(), &Gtk::TreeSelection_Class::wrap_new);
  Glib::wrap_register(gtk_tree_store_get_type(), &Gtk::TreeStore_Class::wrap_new);
  Glib::wrap_register(gtk_tree_view_get_type(), &Gtk::TreeView_Class::wrap_new);
  Glib::wrap_register(gtk_tree_view_column_get_type(), &Gtk::TreeViewColumn_Class::wrap_new);
  Glib::wrap_register(gtk_vbox_get_type(), &Gtk::VBox_Class::wrap_new);
  Glib::wrap_register(gtk_vbutton_box_get_type(), &Gtk::VButtonBox_Class::wrap_new);
  Glib::wrap_register(gtk_vpaned_get_type(), &Gtk::VPaned_Class::wrap_new);
  Glib::wrap_register(gtk_vruler_get_type(), &Gtk::VRuler_Class::wrap_new);
  Glib::wrap_register(gtk_vscale_get_type(), &Gtk::VScale_Class::wrap_new);
  Glib::wrap_register(gtk_vscrollbar_get_type(), &Gtk::VScrollbar_Class::wrap_new);
  Glib::wrap_register(gtk_vseparator_get_type(), &Gtk::VSeparator_Class::wrap_new);
  Glib::wrap_register(gtk_viewport_get_type(), &Gtk::Viewport_Class::wrap_new);
  Glib::wrap_register(gtk_widget_get_type(), &Gtk::Widget_Class::wrap_new);
  Glib::wrap_register(gtk_window_get_type(), &Gtk::Window_Class::wrap_new);
  Glib::wrap_register(gtk_window_group_get_type(), &Gtk::WindowGroup_Class::wrap_new);

  // Register the gtkmm gtypes:
  Gtk::AccelGroup::get_type();
  Gtk::AccelLabel::get_type();
  Gtk::Adjustment::get_type();
  Gtk::Alignment::get_type();
  Gtk::Arrow::get_type();
  Gtk::AspectFrame::get_type();
  Gtk::Bin::get_type();
  Gtk::Box::get_type();
  Gtk::Button::get_type();
  Gtk::ButtonBox::get_type();
  Gtk::Calendar::get_type();
  Gtk::CellRenderer::get_type();
  Gtk::CellRendererPixbuf::get_type();
  Gtk::CellRendererText::get_type();
  Gtk::CellRendererToggle::get_type();
  Gtk::CheckButton::get_type();
  Gtk::CheckMenuItem::get_type();
  Gtk::ColorSelection::get_type();
  Gtk::ColorSelectionDialog::get_type();
  Gtk::Combo::get_type();
  Gtk::ComboDropDown::get_type();
  Gtk::ComboDropDownItem::get_type();
  Gtk::Container::get_type();
  Gtk::Curve::get_type();
  Gtk::Dialog::get_type();
  Gtk::DrawingArea::get_type();
  Gtk::Entry::get_type();
  Gtk::EventBox::get_type();
  Gtk::FileSelection::get_type();
  Gtk::Fixed::get_type();
  Gtk::FontSelection::get_type();
  Gtk::FontSelectionDialog::get_type();
  Gtk::Frame::get_type();
  Gtk::GammaCurve::get_type();
  Gtk::HBox::get_type();
  Gtk::HButtonBox::get_type();
  Gtk::HPaned::get_type();
  Gtk::HRuler::get_type();
  Gtk::HScale::get_type();
  Gtk::HScrollbar::get_type();
  Gtk::HSeparator::get_type();
  Gtk::HandleBox::get_type();
  Gtk::IconFactory::get_type();
  Gtk::Image::get_type();
  Gtk::ImageMenuItem::get_type();
  Gtk::InputDialog::get_type();
  Gtk::Invisible::get_type();
  Gtk::Item::get_type();
  Gtk::Label::get_type();
  Gtk::Layout::get_type();
  Gtk::ListStore::get_type();
  Gtk::Menu::get_type();
  Gtk::MenuBar::get_type();
  Gtk::MenuItem::get_type();
  Gtk::MenuShell::get_type();
  Gtk::MessageDialog::get_type();
  Gtk::Misc::get_type();
  Gtk::Notebook::get_type();
  Gtk::Object::get_type();
  Gtk::OptionMenu::get_type();
  Gtk::Paned::get_type();
#ifndef GTKMM_WIN32
  Gtk::Plug::get_type();
#endif //GTKMM_WIN32
  Gtk::ProgressBar::get_type();
  Gtk::RadioButton::get_type();
  Gtk::RadioMenuItem::get_type();
  Gtk::Range::get_type();
  Gtk::RcStyle::get_type();
  Gtk::Ruler::get_type();
  Gtk::Scale::get_type();
  Gtk::Scrollbar::get_type();
  Gtk::ScrolledWindow::get_type();
  Gtk::Separator::get_type();
  Gtk::SeparatorMenuItem::get_type();
  Gtk::Settings::get_type();
  Gtk::SizeGroup::get_type();
#ifndef GTKMM_WIN32
  Gtk::Socket::get_type();
#endif //GTKMM_WIN32
  Gtk::SpinButton::get_type();
  Gtk::Statusbar::get_type();
  Gtk::Style::get_type();
  Gtk::Table::get_type();
  Gtk::TearoffMenuItem::get_type();
  Gtk::TextBuffer::get_type();
  Gtk::TextChildAnchor::get_type();
  Gtk::TextMark::get_type();
  Gtk::TextTag::get_type();
  Gtk::TextTagTable::get_type();
  Gtk::TextView::get_type();
  Gtk::ToggleButton::get_type();
  Gtk::Toolbar::get_type();
  Gtk::Tooltips::get_type();
  Gtk::TreeSelection::get_type();
  Gtk::TreeStore::get_type();
  Gtk::TreeView::get_type();
  Gtk::TreeViewColumn::get_type();
  Gtk::VBox::get_type();
  Gtk::VButtonBox::get_type();
  Gtk::VPaned::get_type();
  Gtk::VRuler::get_type();
  Gtk::VScale::get_type();
  Gtk::VScrollbar::get_type();
  Gtk::VSeparator::get_type();
  Gtk::Viewport::get_type();
  Gtk::Widget::get_type();
  Gtk::Window::get_type();
  Gtk::WindowGroup::get_type();

} // wrap_init()

} //Gtk


